@@ -29,7 +29,6 @@
 #include "logger.h"
 #include "utils.h"
 
-
 static const char *typename[] = {
     [CONNECTION_TYPE_UNKNOWN] = "Unknown",
     [CONNECTION_TYPE_RAOP]    = "RAOP",
@@ -38,7 +37,6 @@ static const char *typename[] = {
     [CONNECTION_TYPE_HLS]     = "HLS"
 };
 
-
 struct http_connection_s {
     int connected;
 
@@ -69,6 +67,11 @@ struct httpd_s {
     int server_fd6;
 };
 
+const char *
+httpd_get_connection_typename (connection_type_t type) {
+  return typename[type];
+}
+
 int
 httpd_get_connection_socket (httpd_t *httpd, void *user_data) {
     for (int i = 0; i < httpd->max_connections; i++) {
