@@ -214,10 +214,14 @@ raop_ntp_init_socket(raop_ntp_t *raop_ntp, int use_ipv6)
     }
 
     // We're calling recvfrom without knowing whether there is any data, so we need a timeout
-
+    uint32_t recv_timeout_msec = 300; 
+#ifdef _WIN32
+    DWORD tv  = recv_timeout_msec;
+#else
     struct timeval tv;
-    tv.tv_sec = 0;
-    tv.tv_usec = 300000;
+    tv.tv_sec = recv_timeout_msec / (uint32_t) 1000;
+    tv.tv_usec = ((uint32_t) 1000) * (recv_timeout_msec % (uint32_t) 1000);
+#endif
     if (setsockopt(tsock, SOL_SOCKET, SO_RCVTIMEO, CAST &tv, sizeof(tv)) < 0) {
         goto sockets_cleanup;
     }
@@ -299,7 +303,7 @@ raop_ntp_thread(void *arg)
         if (send_len < 0) {
             int sock_err = SOCKET_GET_ERROR();
             logger_log(raop_ntp->logger, LOGGER_ERR, "raop_ntp error sending request. Error %d:%s",
-                     sock_err, strerror(sock_err));
+                     sock_err, SOCKET_ERROR_STRING(sock_err));
         } else {
             // Read response
             response_len = recvfrom(raop_ntp->tsock, (char *)response, sizeof(response), 0, NULL, NULL);
