@@ -346,7 +346,7 @@ void  video_renderer_init(logger_t *render_logger, const char *server_name, vide
 #endif
         gst_element_set_state (renderer_type[i]->pipeline, GST_STATE_READY);
         GstState state;
-        if (gst_element_get_state (renderer_type[i]->pipeline, &state, NULL, 0)) {
+        if (gst_element_get_state (renderer_type[i]->pipeline, &state, NULL, 100 * GST_MSECOND)) {
             if (state == GST_STATE_READY) {
                 logger_log(logger, LOGGER_DEBUG, "Initialized GStreamer video renderer %d", i + 1);
                 if (hls_video && i == 0) {
@@ -484,10 +484,10 @@ void video_renderer_stop() {
      }
 }
 
-void video_renderer_destroy() {
+static void video_renderer_destroy_h26x(video_renderer_t *renderer) {
     if (renderer) {
         GstState state;
-        gst_element_get_state(renderer->pipeline, &state, NULL, 0);
+        gst_element_get_state(renderer->pipeline, &state, NULL, 100 * GST_MSECOND);
         if (state != GST_STATE_NULL) {
             if (!hls_video) {
                 gst_app_src_end_of_stream (GST_APP_SRC(renderer->appsrc));
@@ -510,6 +510,14 @@ void video_renderer_destroy() {
     }
 }
 
+void video_renderer_destroy() {
+    for (int i = 0; i < n_renderers; i++) {
+        if (renderer_type[i]) {
+            video_renderer_destroy_h26x(renderer_type[i]);
+        }
+    }  
+}
+
 gboolean gstreamer_pipeline_bus_callback(GstBus *bus, GstMessage *message, void *loop) {
 
   /* identify which pipeline sent the message */ 
@@ -571,7 +579,7 @@ gboolean gstreamer_pipeline_bus_callback(GstBus *bus, GstMessage *message, void
                      "*** GStreamer may be trying to use non-functional hardware h264 video decoding.\n"
                      "*** Try using option -avdec to force software decoding or use -vs <videosink>\n"
                      "*** to select a videosink of your choice (see \"man uxplay\").\n\n"
-                     "*** Raspberry Pi OS with (unpatched) GStreamer-1.18.4 needs \"-bt709\" uxplay option");
+                     "*** Raspberry Pi models 4B and earlier using Video4Linux2 may need \"-bt709\" uxplay option");
         }
 	g_error_free (err);
         g_free (debug);
@@ -595,10 +603,9 @@ gboolean gstreamer_pipeline_bus_callback(GstBus *bus, GstMessage *message, void
         }
         break;
     case GST_MESSAGE_STATE_CHANGED:
-ESSAGE_STATE_CHANGED:
         if (renderer_type[type]->state_pending && strstr(GST_MESSAGE_SRC_NAME(message), "pipeline")) {
             GstState state;
-            gst_element_get_state(renderer_type[type]->pipeline, &state, NULL,0);
+            gst_element_get_state(renderer_type[type]->pipeline, &state, NULL, 100 * GST_MSECOND);
 	    if (state == GST_STATE_NULL) {
                 gst_element_set_state(renderer_type[type]->pipeline, GST_STATE_PLAYING);
 	    } else if (state == GST_STATE_PLAYING) {
